@@ -1,11 +1,5 @@
-from .mixins import TicTacToe, Hangman, MadLib
 from discord.ext import commands
-
-ALL_GAMES = [
-    TicTacToe,
-    Hangman,
-    MadLib
-]
+from .constants import ALL_GAMES
 
 class Games(commands.Cog, *ALL_GAMES):
     """
@@ -15,4 +9,4 @@ class Games(commands.Cog, *ALL_GAMES):
         super().__init__(bot)
 
 def setup(bot: commands.Bot):
-    bot.add_cog(Games(bot))
+    bot.add_cog(Games(bot))
\ No newline at end of file
